<template>
  <j-modal
    :title="title"
    :width="900"
    :visible="visible"
    :confirmLoading="confirmLoading"
    switchFullscreen
    @ok="handleOk"
    @cancel="handleCancel"
    cancelText="关闭"
  >

    <a-spin :spinning="confirmLoading">
      <a-form-model
        ref="form"
        :model="model"
        :rules="validatorRules"
      >
        <a-row :gutter="24">
          <a-col :span="12">
            <a-form-model-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              prop="partCode"
              label="备件编码"
            >
              <a-input
                placeholder="备件编码自动生成"
                v-model="model.partCode"
                :disabled="true"
              />
            </a-form-model-item>
          </a-col>
          <a-col :span="12">
            <a-form-model-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              prop="partCategory"
              label="备件分类"
            >
              <!-- <a-input
                placeholder="请输入备件分类"
                v-model="model.partCategory"
              /> -->
              <j-dict-select-tag
                allow-clear
                :disabled="false"
                placeholder="请选择备件分类"
                :triggerChange="true"
                dictCode="spare_part_category"
                v-model="model.partCategory"
              />
            </a-form-model-item>
          </a-col>

        </a-row>
        <a-row :gutter="24">
          <a-col :span="12">
            <a-form-model-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              prop="partName"
              label="备件名称"
            >
              <a-input
                placeholder="请输入备件名称"
                v-model="model.partName"
              />
            </a-form-model-item>
          </a-col>
          <a-col :span="12">
            <a-form-model-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              prop="partModel"
              label="备件型号"
            >
              <a-input
                placeholder="请输入备件型号"
                v-model="model.partModel"
              />
            </a-form-model-item>
          </a-col>
        </a-row>
        <a-row :gutter="24">
          <a-col :span="12">
            <a-form-model-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              prop="partSpecification"
              label="备件规格"
            >
              <a-input
                placeholder="请输入备件规格"
                v-model="model.partSpecification"
              />
            </a-form-model-item>
          </a-col>
          <a-col :span="12">
            <a-form-model-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              prop="storehouse"
              label="存放仓库"
            >
              <a-input
                placeholder="请输入存放仓库"
                v-model="model.storehouse"
              />
            </a-form-model-item>
          </a-col>
        </a-row>
        <a-row :gutter="24">
          <a-col :span="12">
            <a-form-model-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              prop="unit"
              label="计量单位"
            >
              <a-input
                placeholder="请输入计量单位"
                v-model="model.unit"
              />
            </a-form-model-item>
          </a-col>
          <a-col :span="12">
            <a-form-model-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              prop="manufacturingEnterprise"
              label="制造企业"
            >
              <a-input
                placeholder="请输入制造企业"
                v-model="model.manufacturingEnterprise"
              />
            </a-form-model-item>
          </a-col>
        </a-row>
        <a-row :gutter="24">
          <a-col :span="12">
            <a-form-model-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              prop="periodOfValidity"
              label="有效期(天)"
            >
              <a-input-number
                style="width: 100%"
                :min="0"
                :precision="0"
                v-model="model.periodOfValidity"
              />
            </a-form-model-item>
          </a-col>

          <a-col :span="12">
            <a-form-model-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              prop="inventoryWarning"
              label="库存预警值"
            >
              <a-input-number
                style="width: 100%"
                :min="0"
                v-model="model.inventoryWarning"
              />
            </a-form-model-item>
          </a-col>
        </a-row>
        <a-row :gutter="24">
          <a-col :span="12">
            <a-form-model-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              prop="inventoryMax"
              label="最大备货库存"
            >
              <a-input-number
                style="width: 100%"
                :min="0"
                v-model="model.inventoryMax"
              />
            </a-form-model-item>
          </a-col>
          <a-col :span="12">
            <a-form-model-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              prop="inventoryMin"
              label="最小备货库存"
            >
              <a-input-number
                style="width: 100%"
                :min="0"
                v-model="model.inventoryMin"
              />
            </a-form-model-item>
          </a-col>
        </a-row>
        <a-row :gutter="24">
          <a-col :span="24">
            <a-form-model-item
              :labelCol="{xs: { span: 24 }, sm: { span: 3 }}"
              :wrapperCol="{xs: { span: 24 },sm: { span: 21 }}"
              prop="remark"
              label="备注"
            >
              <a-textarea
                placeholder="请输入备注"
                v-model="model.remark"
              />
            </a-form-model-item>
          </a-col>
        </a-row>
      </a-form-model>
    </a-spin>
  </j-modal>
</template>

<script>
import { getAction, httpAction } from '@api/manage'
import moment from "moment"

export default {
  name: "EamSparePartsModal",
  data() {
    return {
      title: "操作",
      visible: false,
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 6 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 18 }
      },

      confirmLoading: false,
      validatorRules: {
        partName: [
          { required: true, message: '请输入备件名称' }
        ]
      },
      url: {
        add: "/eam/eamSpareParts/add",
        edit: "/eam/eamSpareParts/edit",
        generateRequisitionCode: "sys/sysBusinessCodeRule/generateBusinessCodeSeq"
      },
    }
  },
  created() {
  },
  methods: {
    add() {
      const that = this
      let params = {
        businessCode: "SparePartCodeRule"
      }
      getAction(that.url.generateRequisitionCode, params).then((res) => {
        if (res.success) {
          this.model = {
            partCode: res.result
          }
        } else {
          that.$message.warning(res.message);
        }
      })
      //初始化默认值
      that.edit(this.model);
    },
    edit(record) {
      this.model = Object.assign({}, record);
      this.visible = true;
    },
    close() {
      this.$emit('close');
      this.visible = false;
      this.$refs.form.clearValidate();
    },
    handleOk() {
      const that = this;
      // 触发表单验证
      this.$refs.form.validate(valid => {
        if (valid) {
          that.confirmLoading = true;
          let httpurl = '';
          let method = '';
          if (!this.model.id) {
            httpurl += this.url.add;
            method = 'post';
          } else {
            httpurl += this.url.edit;
            method = 'put';
          }
          httpAction(httpurl, this.model, method).then((res) => {
            if (res.success) {
              that.$message.success(res.message);
              that.$emit('ok');
            } else {
              that.$message.warning(res.message);
            }
          }).finally(() => {
            that.confirmLoading = false;
            that.close();
          })
        } else {
          return false;
        }
      })
    },
    handleCancel() {
      this.close()
    }
  }
}
</script>

<style lang="less" scoped>
</style>